@@ -4,19 +4,17 @@ OC.L10N.register(
     "Today" : "Heddiw",
     "Week" : "Wythnos",
     "All" : "Popeth",
-    "Cancel" : "Diddymu",
-    "Save" : "Cadw",
     "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
     "No users or groups" : "Dim defnyddwyr na grwpiau",
-    "can edit" : "yn gallu golygu",
     "Unable to delete the share." : "Methu dileu'r gyfran.",
     "Unable to change permissions." : "Methu newid caniatâd.",
     "Edit" : "Golygu",
     "Copied" : "Copïwyd",
-    "Can not copy" : "Methu copïo",
     "Download" : "Llwytho i lawr",
     "Delete" : "Dileu",
     "Unshare" : "Dad-rannu",
+    "Cancel" : "Diddymu",
+    "Save" : "Cadw",
     "No errors" : "Dim gwallau",
     "Open your browser console for more details" : "Agorwch eich consol porwr am fwy o fanylion",
     "Last modified" : "Newidiwyd diwethaf",
