@@ -9,38 +9,41 @@ OC.L10N.register(
     "Completed" : "הושלם",
     "Tasks" : "משימות",
     "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
-    "Add List…" : "הוספת רשימה…",
-    "New List" : "רשימה חדשה",
-    "Cancel" : "ביטול",
-    "Save" : "שמירה",
-    "The name \"{calendar}\" is already used." : "השם „{calendar}” כבר נמצא בשימוש.",
-    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
+    "Default list" : "רשימת בררת מחדל",
+    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
+    "Hidden" : "מוסתר",
+    "Visible" : "גלוי",
+    "Automatic" : "אוטומטי",
     "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
     "No users or groups" : "אין משתמשים או קבוצות",
-    "can edit" : "יש הרשאת עריכה",
     "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
     "Unable to delete the share." : "לא ניתן למחוק את השיתוף.",
     "Unable to change permissions." : "לא ניתן לשנות הרשאות.",
     "Edit" : "עריכה",
     "Copy private link" : "העתקת קישור פרטי",
     "Copied" : "הועתק",
-    "Can not copy" : "לא ניתן להעתיק",
     "Download" : "הורדה",
     "Delete" : "מחיקה",
     "Unshare" : "ביטול שיתוף",
+    "Cancel" : "ביטול",
+    "Save" : "שמירה",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "פעולה זו תמחק את לוח השנה „{calendar}” ואת כל האירועים והמשימות הקשורים אליו.",
     "This will unshare the calendar \"{calendar}\"." : "פעולה זו תבטל את שיתוף לוח השנה „{calendar}”.",
+    "This will delete the list \"{list}\" and all corresponding tasks." : "פעולה זו תמחק את הרשימה „{list}” ואת כל המשימות הקשורות אליה.",
+    "This will unshare the list \"{list}\"." : "פעולה זו תבטל את שיתוף הרשימה „{list}”.",
     "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
+    "List link copied to clipboard." : "הקישור לרשימה הועתק ללוח הגזירים.",
     "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
+    "List link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור לרשימה ללוח הגזירים.",
+    "The name \"{calendar}\" is already used." : "השם „{calendar}” כבר נמצא בשימוש.",
+    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
+    "An error occurred, unable to delete the list." : "אירעה שגיאה, אין אפשרות למחוק את הרשימה.",
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["לוח השנה יימחק בעוד שנייה","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות"],
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["שיתוף לוח השנה יפסק בעוד שנייה","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות"],
+    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["הרשימה תימחק בעוד שנייה","הרשימה תימחק בעוד שתי שניות","הרשימה תימחק בעוד {countdown} שניות","הרשימה תימחק בעוד {countdown} שניות"],
+    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["שיתוף הרשומה יבוטל בעוד שנייה אחת","שיתוף הרשומה יבוטל בעוד שתי שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["משותף עם ישות אחת","משותף עם {num} ישויות","משותף עם {num} ישויות","משותף עם {num} ישויות"],
-    "Default list" : "רשימת בררת מחדל",
-    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
-    "Hidden" : "מוסתר",
-    "Visible" : "גלוי",
-    "Automatic" : "אוטומטי",
     "Delete all completed tasks." : "מחיקת כל המשימות שהושלמו.",
     "Delete completed tasks." : "מחיקת המשימות שהושלמו.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "כל המשימות שהושלמו נמחקו מהיומן „{calendar}”.",
@@ -48,6 +51,10 @@ OC.L10N.register(
     "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["פעולה זו תמחק משימה שהושלמה ואת תת־המשימות שלה מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”."],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["לא ניתן למחוק משימה אחת.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות."],
+    "Add an important task to \"{calendar}\"…" : "הוספת משימה חשובה אל „{calendar}”",
+    "Add a task due today to \"{calendar}\"…" : "הוספה משימה שמועד תפוגתה הוא היום אל „{calendar}”",
+    "Add a current task to \"{calendar}\"…" : "הוספת משימה נוכחית אל „{calendar}”",
+    "Add a task to \"{calendar}\"…" : "הוספת משימה אל „{calendar}”",
     "Load all completed tasks." : "טעינת כל המשימות שהושלמו.",
     "Change sort order" : "שינוי סדר מיון",
     "Relevance" : "רלוונטיות",
@@ -73,8 +80,6 @@ OC.L10N.register(
     "Add subtask" : "הוספת תת־משימה",
     "Show subtasks" : "הצגת תת־משימות",
     "Hide subtasks" : "הסתרת תת־משימות",
-    "Show completed subtasks" : "הצגת תת־משימות שהושלמו",
-    "Hide completed subtasks" : "הסתרת תת־משימות שהושלמו",
     "Delete task" : "מחיקת משימה",
     "[Yesterday]" : "[אתמול]",
     "[Today]" : "[היום]",
@@ -91,33 +96,22 @@ OC.L10N.register(
     "[Completed tomorrow at] LT" : "[תושלם מחר בשעה] LT",
     "[Completed] L [at] LT" : "[הושלמה] L [בשעה] LT",
     "Add a subtask to \"{task}\"…" : "הוספת תת־משימה אל „{task}”",
-    "An error occurred, unable to delete the task." : "אירעה שגיאה, אין אפשרות למחוק את המשימה.",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["המשימה תימחק בעוד שנייה","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות"],
-    "Add a task to \"{task}\"…" : "הוספת משימה אל „{task}”",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
-    "Add an important task to \"{calendar}\"…" : "הוספת משימה חשובה אל „{calendar}”",
-    "Add a task due today to \"{calendar}\"…" : "הוספה משימה שמועד תפוגתה הוא היום אל „{calendar}”",
-    "Add a current task to \"{calendar}\"…" : "הוספת משימה נוכחית אל „{calendar}”",
-    "Add a task to \"{calendar}\"…" : "הוספת משימה אל „{calendar}”",
     "Tomorrow" : "מחר",
-    "Set start date" : "קביעת תאריך התחלה",
-    "Set start time" : "הגדרת זמן התחלה",
-    "Set due date" : "הגדרת תאריך יעד",
-    "Set due time" : "הגדרת מועד יעד",
+    "Add List…" : "הוספת רשימה…",
+    "New List" : "רשימה חדשה",
     "All day" : "כל היום",
-    "Select a calendar" : "הגדרת יומן",
     "Select a classification" : "בחירת סיווג",
     "Select a status" : "בחירת מצב",
-    "Select categories" : "בחירת קטגוריות",
-    "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
-    "Loading task from server." : "נטענת משימה מהשרת.",
-    "Task not found!" : "לא אותרה משימה!",
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
     "Needs action" : "נדרשת התערבות",
     "In process" : "בתהליך",
     "Canceled" : "מבוטלת",
+    "Loading task from server." : "נטענת משימה מהשרת.",
+    "Task not found!" : "לא אותרה משימה!",
     "[Starts today]" : "[מתחילה היום]",
     "[Starts tomorrow]" : "[מתחילה מחר]",
     "[Starts on] LL" : "[מתחילה במועד] LL",
@@ -129,6 +123,7 @@ OC.L10N.register(
     "[Starts on] LL [at] LT" : "[מתחילה ביום] LL [בשעה] LT",
     "[Started yesterday at] LT" : "[החלה אתמול בשעה] LT",
     "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT",
+    "Set start date" : "קביעת תאריך התחלה",
     "[Due today]" : "[מועד התפוגה הוא היום]",
     "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
     "[Due on] LL" : "[מועד התפוגה הוא] LL",
@@ -140,13 +135,11 @@ OC.L10N.register(
     "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
     "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
     "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
-    "Last modified {date}" : "שינוי אחרון ב־{date}",
-    "Created {date}" : "נוצרה ב־{date}",
-    "Completed {date}" : "הושלמה ב־{date}",
-    "No priority assigned" : "לא הוגדרה עדיפות",
-    "Priority {priority}: high" : "עדיפות {priority}: גבוהה",
-    "Priority {priority}: medium" : "עדיפות {priority}: בינונית",
+    "Set due date" : "הגדרת תאריך יעד",
     "Priority {priority}: low" : "עדיפות {priority}: נמוכה",
+    "Priority {priority}: medium" : "עדיפות {priority}: בינונית",
+    "Priority {priority}: high" : "עדיפות {priority}: גבוהה",
+    "No priority assigned" : "לא הוגדרה עדיפות",
     "{percent} % completed" : "{percent} % הושלמו",
     "Successfully created the task." : "המשימה נוצרה בהצלחה.",
     "Could not delete the task." : "לא ניתן למחוק את המשימה.",
